@@ -27,7 +27,7 @@ public:
              rho_alpha, sd_alpha_0, sd_alpha_x)
   {}
 
-  BSAMCMCResult operator()(const int n_rep, const arma::vec& sampler_jump) const;
+  BSAMCMCResult operator()(const int n_rep, const std::vector<arma::vec>& sampler_jump) const;
   
 private:
   const double el2;
